library("tidyverse")
library("poppr")
library("cowplot")
library("ggrepel")
library("ggalt")

mydat <- tibble::tribble(
    ~region,             ~long,              ~lat,  ~n,     ~country,
"Australia",  136.998543415789, -25.1829968212449,  6L,  "Australia",
       "CA", -120.706417719523,  36.7131257759508, 18L,        "USA",
       "CO", -105.070305932926,  38.5808740446839, 42L,        "USA",
   "France",  3.22697920310042,   46.166861050188, 22L,     "France",
       "ID", -114.692134022201,  45.4548074452151,  1L,        "USA",
   "Mexico", -103.598038343608,  24.2114148623838, 18L,     "Mexico",
       "MI", -85.8953751253794,  45.3008943304958, 62L,        "USA",
       "MN", -93.6029323751741,  46.9022635595409, 11L,        "USA",
       "ND", -98.2043120611282,  47.4364311944871, 60L,        "USA",
       "NE", -97.5477447509766,  41.7149637662447, 47L,        "USA",
       "NY",  -74.716949015916,  42.1532112275711,  1L,        "USA",
       "OR", -121.304633512335,  44.8775748721624, 17L,        "USA",
       "WA",   -122.5348777701,  47.4854069771023, 59L,        "USA",
       "WI", -89.5409875850088,  44.9597030030083,  2L,        "USA"
)
world <- map_data("world") %>% 
  as_tibble() %>%
  filter(region %in% mydat$region)
states <- map_data("state") %>% 
  as_tibble() %>%
  inner_join(data_frame(region = tolower(state.name), state = state.abb)) %>%
  select(-region)
names(states) <- gsub("state", "region", names(states))
whole <- bind_rows(states, world) %>% mutate(country = case_when(nchar(region) == 2 ~ "USA", TRUE ~ region))
my_maps <- vector(length = 3, mode = "list")
names(my_maps) <- c("USA", "France", "Australia")
for (i in c("USA", "France", "Australia")) {
  if (i == "USA") i <- c(i, "Mexico")
  w <- filter(whole, country %in% i)
  m <- filter(mydat, country %in% i)
  gg <- ggplot()
  gg <- gg + geom_map(data = w, map = w,
                      aes(x=long, y=lat, map_id = region),
                      color="grey25", fill="white", size = 0.5)
  gg <- gg + geom_point(aes(x=long, y = lat, size = n), data = m, 
                        color = "black", pch = 21, fill = "yellow")
  gg <- gg + geom_label_repel(aes(x = long, y = lat, label = paste0("n=",n)), data = m, )
  gg <- gg + scale_size_continuous(limits = range(mydat$n), guide = "none")
  my_maps[[i[1]]] <- gg + coord_map() + ggplot2::theme_void(base_size = 16, base_family = "Lato")
  
}
d <- mydat %>% group_by(country) %>% summarize(n = 1)
world <- map_data("world") %>% filter(region != "Antarctica") %>% left_join(d, by = c("region" = "country")) %>% as_tibble

gg <- ggplot()
gg <- gg + geom_cartogram(data = world, map = world,
                    aes(x=long, y=lat, map_id = region, fill = n),
                    size = 0.5)
gg <- gg + scale_fill_continuous(low = "black", high = "yellow", na.value = "grey35", limits = c(0, 1), guide = "none")
gg <- gg + coord_proj("+proj=wintri")
gg <- gg + theme_grey() + theme(axis.text = element_blank(), axis.ticks = element_blank(), text = element_blank())
ggsave(gg, filename = "inset.svg")
p <- cowplot::plot_grid(plotlist = my_maps)
set.seed(54000)
cowplot::ggsave(p, filename = "maps.svg")
